[U-Boot] [PATCH v1 2/3] wdt: Timeout better to be in microseconds

Andy Shevchenko andriy.shevchenko at linux.intel.com
Wed Jul 5 17:44:07 UTC 2017


Timeout in some abstract ticks is not what we are applying to get
deterministic behaviour.

Convert name to show explicitly that we are using microseconds (for
watchdog it's more than precise).

No functional change intended.

Signed-off-by: Andy Shevchenko <andriy.shevchenko at linux.intel.com>
---
 drivers/watchdog/wdt-uclass.c | 4 ++--
 include/wdt.h                 | 8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/watchdog/wdt-uclass.c b/drivers/watchdog/wdt-uclass.c
index bb9ae80866..1715a98452 100644
--- a/drivers/watchdog/wdt-uclass.c
+++ b/drivers/watchdog/wdt-uclass.c
@@ -13,14 +13,14 @@
 
 DECLARE_GLOBAL_DATA_PTR;
 
-int wdt_start(struct udevice *dev, u64 timeout, ulong flags)
+int wdt_start(struct udevice *dev, u64 timeout_us, ulong flags)
 {
 	const struct wdt_ops *ops = device_get_ops(dev);
 
 	if (!ops->start)
 		return -ENOSYS;
 
-	return ops->start(dev, timeout, flags);
+	return ops->start(dev, timeout_us, flags);
 }
 
 int wdt_stop(struct udevice *dev)
diff --git a/include/wdt.h b/include/wdt.h
index 0b5f05851a..115e8c6baf 100644
--- a/include/wdt.h
+++ b/include/wdt.h
@@ -21,12 +21,12 @@
  * Start the timer
  *
  * @dev: WDT Device
  * @timeout: Number of ticks before timer expires
  * @flags: Driver specific flags. This might be used to specify
  * which action needs to be executed when the timer expires
  * @return: 0 if OK, -ve on error
  */
-int wdt_start(struct udevice *dev, u64 timeout, ulong flags);
+int wdt_start(struct udevice *dev, u64 timeout_us, ulong flags);
 
 /*
  * Stop the timer, thus disabling the Watchdog. Use wdt_start to start it again.
@@ -67,12 +67,12 @@ struct wdt_ops {
 	 * Start the timer
 	 *
 	 * @dev: WDT Device
 	 * @timeout: Number of ticks before the timer expires
 	 * @flags: Driver specific flags. This might be used to specify
 	 * which action needs to be executed when the timer expires
 	 * @return: 0 if OK, -ve on error
 	 */
-	int (*start)(struct udevice *dev, u64 timeout, ulong flags);
+	int (*start)(struct udevice *dev, u64 timeout_us, ulong flags);
 	/*
 	 * Stop the timer
 	 *
@@ -21,12 +21,12 @@
  *
  * @dev: WDT Device
- * @timeout: Number of ticks before timer expires
+ * @timeout_us: Number of microseconds before timer expires
  * @flags: Driver specific flags. This might be used to specify
  * which action needs to be executed when the timer expires
@@ -67,12 +67,12 @@ struct wdt_ops {
 	 *
 	 * @dev: WDT Device
-	 * @timeout: Number of ticks before the timer expires
+	 * @timeout_us: Number of microseconds before the timer expires
 	 * @flags: Driver specific flags. This might be used to specify
 	 * which action needs to be executed when the timer expires
-- 
2.11.0



More information about the U-Boot mailing list